@@ -17,7 +17,6 @@ import re
 from datatypes.collections import ListIterator
 from datatypes import property as cachedproperty
 
-from . import decorators
 from .utils import make_list, get_objects, make_dict, make_hash
 from .interface import get_interfaces
 from .compat import *
@@ -66,7 +65,9 @@ class Iterator(ListIterator):
         ret = False
         if self.query.bounds.has_more():
             cursor = self.cursor()
-            if cursor.rowcount == -1:
+            # https://www.psycopg.org/docs/cursor.html#cursor.rowcount says that
+            # future versions of the spec reserve the right to return None
+            if cursor.rowcount == -1 or cursor.rowcount is None:
                 try:
                     if self[self.query.bounds.find_more_index()]:
                         ret = True
@@ -249,7 +250,6 @@ class Iterator(ListIterator):
 
 
 class Bounds(object):
-
     @property
     def limit(self):
         l = self._limit
@@ -402,6 +402,7 @@ class Field(object):
         self.operator = kwargs.pop("operator", None)
         self.is_list = kwargs.pop("is_list", False)
         self.direction = kwargs.pop("direction", None) # 1 = ASC, -1 = DESC
+        self.or_clause = False
         self.kwargs = kwargs
 
         self.set_name(field_name)
@@ -504,7 +505,6 @@ class Query(object):
     bounds_class = Bounds
     iterator_class = Iterator
 
-
     @property
     def interface(self):
         return self.orm_class.interface if self.orm_class else None
@@ -536,13 +536,32 @@ class Query(object):
 
         return schemas
 
-    def __init__(self, orm_class=None, **kwargs):
+    @property
+    def OR(self):
+        """Wraps left and right field statements with an OR clause, you can chain
+        as many OR calls as you want to create an any length OR clause
 
+        I don't love that I had to use OR instead of or but "or" is a reserved
+        keyword and I thought OR was better than like _or or _or_
+
+        :Example:
+            self.eq_foo(1).OR.eq_foo(5).OR.eq_foo(10) # (foo=1 OR foo=5 OR foo=10)
+        """
+        self.fields_where[-1].or_clause = True
+        return self
+
+    @property
+    def AND(self):
+        """This is just here for completeness with .OR since, by default, any
+        statements will be joined by AND"""
+        self.fields_where[-1].or_clause = False
+        return self
+
+    def __init__(self, orm_class=None, **kwargs):
         # needed to use the db querying methods like get(), if you just want to build
         # a query then you don't need to bother passing this in
         self.orm_class = orm_class
         self.reset()
-        self.kwargs = kwargs
 
     def reset(self):
         #self.interface = None
@@ -552,6 +571,7 @@ class Query(object):
         self.fields_where = self.fields_where_class()
         self.fields_sort = self.fields_sort_class()
         self.bounds = self.bounds_class()
+        self.compounds = []
 
     def ref(self, orm_classpath):
         """
@@ -655,6 +675,21 @@ class Query(object):
     def create_iterator(self, query):
         return self.orm_class.iterator_class(query) if self.orm_class else self.iterator_class(query)
 
+    def append_compound(self, operator, queries, **kwargs):
+        """Internal method used by .intersect(), .union(), and .difference()"""
+        for i, query in enumerate(queries):
+            if self.fields_select:
+                if not query.fields_select:
+                    if self.schema == query.schema:
+                        query.select(*self.fields_select.names())
+
+            else:
+                if i == 0 and query.fields_select:
+                    self.select(*query.fields_select.names())
+
+        self.compounds.append((operator, queries))
+        return self
+
     def append_operation(self, operator, field_name, field_val=None, **kwargs):
         kwargs["operator"] = operator
         f = self.create_field(field_name, field_val, **kwargs)
@@ -722,6 +757,46 @@ class Query(object):
             self.set_field(field_name, field_val)
         return self
 
+    def intersect(self, *queries, **kwargs):
+        """Intersect a set of queries. Returns rows that are common in all the 
+        queries.
+
+        Compound Query instances will only return values, not Orm instances
+
+        :Example:
+            Query().intersect(
+                Query().select_foo(),
+                Query().select_foo(),
+            ).all()
+
+        https://www.sqlite.org/syntax/compound-operator.html
+
+        :param *queries: two or more queries, they should all select the same
+            field types, the first query sets the name of the return columns
+        """
+        return self.append_compound("intersect", queries, **kwargs)
+
+    def union(self, *queries, **kwargs):
+        """Return all the rows from all the queries
+
+        See .intersect() since this works very similar
+        """
+        return self.append_compound("union", queries, **kwargs)
+
+    def difference(self, *queries, **kwargs):
+        """Return everything in the first query that isn't in any of the other
+        queries.
+
+        Return the rows with rows in the first query that are not in the other
+        queries
+
+        This is named .difference() instead of .except() because except is a python
+        keyword.
+
+        See .intersect() since this works very similar
+        """
+        return self.append_compound("except", queries, **kwargs)
+
     def is_field(self, field_name, field_val=None, **field_kwargs):
         return self.append_operation("eq", field_name, field_val, **field_kwargs)
     def eq_field(self, field_name, field_val=None, **field_kwargs):
@@ -975,7 +1050,7 @@ class Query(object):
         return -- mixed -- depends on the backend and the type of query
         """
         i = self.interface
-        return i.query(query_str, *query_args, **query_options)
+        return i.raw(query_str, *query_args, **query_options)
 
     def execute(self, method_name, **kwargs):
         i = self.interface
